@@ -236,8 +236,7 @@ void Titraqform::setupActions(void)
     m_pFilequitact = new QAction(trUtf8("Exit"), trUtf8("E&xit"), CTRL+Key_Q, this, "Exit");
     if (m_pFilequitact == NULL)     // Sanity check
         throw Genexcept("Main window file quit action creation failed.");
-    connect(m_pFilequitact, SIGNAL(activated()), this, SLOT(close()));
-    connect(m_pFilequitact, SIGNAL(activated()), qApp, SLOT(quit()));
+    connect(m_pFilequitact, SIGNAL(activated()), this, SLOT(quitApp()));
 
     // Cut action
     m_pCutact = new QAction(trUtf8("Cut"), Cutiset, trUtf8("&Cut"), CTRL+Key_X, this, "Cut");
