@@ -270,10 +270,10 @@ void Titraqform::loadData(QTextStream &Tstream)
         Asline.skipWhiteSpace();    // Remove whitespaces
         Remark = Asline.read();     // Copy the remark field
 
-        // Get rid of surrounding double quotes
-        QRegExp Quoted("\"(.*)\"$");
-        Quoted.search(Remark);
-        Remark = Quoted.cap(Quoted.numCaptures());
+        QRegExp Quoted("\"(.*[^\\\\])\"");                  // Get rid of
+        Quoted.search(Remark);                              // surrounding double
+        Remark = Quoted.cap(Quoted.numCaptures());          // quotes, and
+        Remark.replace(QRegExp("\\\\(.)"), QString("\\1")); // escape backslashes
 
         if (!Remark.isEmpty())
             m_pMaintable->setText(nIter, TITRAQ_IDXREMARK, Remark);
@@ -418,12 +418,16 @@ void Titraqform::saveData(QTextStream &Tstream)
             Tstream << trUtf8(" ") << Tempfield;                    // Save acct field text
 
         Tempfield = m_pMaintable->text(nIter, TITRAQ_IDXREMARK);    // Load remark field text
+        Tstream << trUtf8(" \"");                                   // Save beginning double quote
         if (Tempfield != NULL) {
             Strsearch = QRegExp::escape(Tempfield);                 // Incoming string escaped
             Stripper.search(Strsearch);
-            Tempfield.truncate(Stripper.pos());
-            Tstream << trUtf8(" \"") << Tempfield << trUtf8("\"");  // Save remark field text
+            Tempfield.truncate(Stripper.pos());                     // Cut off whitespace
+            Tempfield.replace(QChar('\\'), QString("\\\\"));        // Escape back slashes
+            Tempfield.replace(QChar('\"'), QString("\\\""));        // Escape double quotes
+            Tstream << Tempfield;                                   // Save remark field text
         }
+        Tstream << trUtf8("\"");                                    // Save ending double quote
 
         Tstream << endl;                                            // Append a newline
     }
