@@ -563,6 +563,37 @@ void Titraqform::saveName(void)
     }
 }
 
+//
+// Close current document, and then quit the application
+//
+void Titraqform::quitApp(void)
+{
+    int nResult = 0;
+
+    if (m_pMaintable->isDirty()) {
+        nResult = QMessageBox::information(this, QString(TITRAQ_APPTITLE)
+                + ' ' + asgui_version.v_short, trUtf8(TITRAQ_SAVEFIRST),
+                  trUtf8("&Save"), trUtf8("&Discard"), trUtf8("Cancel"), 0, 2);
+
+        switch (nResult) {      // Maybe save before closing
+        case 0: // Save first
+            this->saveFile();   // Save changes first
+            break;
+        case 1: // Don't save first
+            m_pMaintable->setDirty(false);
+            break;
+        case 2: // Do nothing
+        default:
+            return; // Go away without closing
+            break;
+        }
+    }
+
+    // We should be clean now, but double check just in case
+    if (!m_pMaintable->isDirty())
+        qApp->quit();
+}
+
 //
 // Close current document, displaying in main window
 //
@@ -1051,7 +1082,8 @@ void Titraqform::updateTask(const QString &Taskup)
 //    pTask = static_cast<RtTableItem *>(m_pMaintable->item(m_pMaintable->currentRow(), TITRAQ_IDXTASK));
 //    pTask->setText(Taskup);
 
-    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXTASK, Taskup);
+    // Don't try to use the Taskup string, because it ignores autocompletion
+    m_pMaintable->setText(m_pMaintable->currentRow(), TITRAQ_IDXTASK, m_pTasks->currentText());
 }
 
 //
@@ -1512,22 +1544,38 @@ void Titraqform::syncIiop(void)
         }
 
         // Open an account object on the remote server
-        Account_var Account = Asdbase->Open("/tmp/corbadb.txt"); // Security problem!
+        Account_var Account = Asdbase->Open("/tmp/events.as");
         if (CORBA::is_nil(Account)) { // Verify sanity
             m_pStatbar->message(trUtf8("Could not create an account object on the server"));
             qWarning("Could not create an account object on the server\n");
             return;
         }
 
-        // Fill an account object to marshall and transmit
+        // Fill account log object(s) to marshall and transmit
         int nRow = m_pMaintable->currentRow();
-        Singlerow.nDate = m_pMaintable->text(nRow, TITRAQ_IDXDATE).toInt();
-        Singlerow.nTime = m_pMaintable->text(nRow, TITRAQ_IDXSTART).toInt();
-        Singlerow.szName = CORBA::string_dup(m_pMaintable->text(nRow, TITRAQ_IDXUSER));
-        Singlerow.szTask = CORBA::string_dup(m_pMaintable->text(nRow, TITRAQ_IDXTASK));
-        Singlerow.szRemark = CORBA::string_dup(m_pMaintable->text(nRow, TITRAQ_IDXREMARK));
+        QTableSelection Select = m_pMaintable->selection(0);    // Capture selected rows
+        int nTotal = Select.bottomRow() - Select.topRow() + 1;  // Total rows selected
+
+        // Remember, CORBA::stri_dup creates smart pointers
+        for (int nIter = 0; nIter < nTotal; nIter++) {
+            Singlerow.szUser   = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXUSER));
+            Singlerow.szGuid   = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXGUID));
+            Singlerow.szCrc    = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXCRC).remove("0x"));
+            Singlerow.szRev    = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXREV));
+            Singlerow.szDate   = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXDATE));
+            Singlerow.szStart  = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXSTART));
+            Singlerow.szFinish = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXFINISH));
+            Singlerow.szAmount = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXAMOUNT));
+//            Singlerow.nRev     = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXREV).toUInt();
+//            Singlerow.nDate    = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXDATE).toUInt();
+//            Singlerow.nStart   = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXSTART).toUInt();
+//            Singlerow.nFinish  = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXFINISH).toUInt();
+//            Singlerow.nAmount  = m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXAMOUNT).toUInt();
+            Singlerow.szTask   = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXTASK));
+            Singlerow.szRemark = CORBA::string_dup(m_pMaintable->text(Select.topRow() + nIter, TITRAQ_IDXREMARK));
+            Account->Log(Singlerow); // Finally transmit to server
+        }
 
-        Account->Log(Singlerow); // Finally transmit to server
         m_pStatbar->message(trUtf8("Successful transmission of accounting data"));
     }
     catch (const CORBA::Exception &Corbex) {
